#!/bin/bash

SETTINGS_FILE_NAME=settings.php

DATABASE_SECTION_VERIFY_LINE='$databases = array ('

SETTINGS_SET_DATABASE_NAME_PARAM_NAME='database'
SETTINGS_SET_DATABASE_SERVER_ADDRESS_PARAM_NAME='host'
SETTINGS_SET_DATABASE_USER_NAME_PARAM_NAME='username'
SETTINGS_SET_DATABASE_PASSWORD_PARAM_NAME='password'

PATH_TO_BACKUP_A_FILE_SCRIPT='/root/scripts/backup-a-file.sh'

if ! [ -s "$PATH_TO_BACKUP_A_FILE_SCRIPT" ]; then
	echo "ERROR! Internal problem!"
	echo "Cannot find the backup-a-file script! Aborting ..."
	echo "Make sure the backup-a-file script exists and accessible or edit this script."
	echo "Aborting ..."
	exit 1
fi

if [ "$1" == "" -o "$2" == "" -o "$3" == "" -o "$4" == "" -o "$5" == "" ]; then
	echo "ERROR! Wrong Input."
	echo "Usage: $0 <path_to_a_drupal_site_dir> <new_sql_server_ip> <new_sql_db_name> <new_sql_username> <new_sql_password> [optional: type anything for this parameter to skip original file backup]"

else
	if [ "$1" == "." ]; then
		SITE_DIR=`pwd`
	else
		SITE_DIR=$1
	fi

	if ! [ -d "$SITE_DIR" ]; then
		echo "ERROR! given dir is an invalid dir!"
		echo "Aborting ..."
		exit 1
	else
		cd $SITE_DIR
		#pwd
	fi

	if ! [ -s sites/default/"$SETTINGS_FILE_NAME" ]; then
		echo "INFO: the dir '$SITE_DIR' is not a valid drupal site."
		echo "Could not find a valid 'settings.php' file as '$SITE_DIR/sites/default/$SETTINGS_FILE_NAME'"
		echo "Aborting"
		exit 1
	else
		SETTINGS_FILE_PATH=$SITE_DIR/sites/default/$SETTINGS_FILE_NAME	
	
		cat $SETTINGS_FILE_PATH | grep "$DATABASE_SECTION_VERIFY_LINE" > /dev/null

		if ! [ "$?" == 0 ]; then
			echo "ERROR! the settings.php file supplied seems invalid."
			echo "Aborting ..."
			exit 1
		fi

		if [ "$6" == "" ]; then
			echo "Backing up original file ..."

			$PATH_TO_BACKUP_A_FILE_SCRIPT $SETTINGS_FILE_PATH > /dev/null

			if ! ["$?" == 0]; then
				echo "ERROR!  Something went wrong with the backup process. 
Aborting …"

exit 1
			fi
		else
			echo "NOTE: As requested, skipping backup."
		fi

		echo "Updating settings file with new data ..."
	
		sed --follow-symlinks -i "/\*/b; s/\(\s*'$SETTINGS_SET_DATABASE_SERVER_ADDRESS_PARAM_NAME'\s*=>\s*\)'.*'/\1'$2'/" $SETTINGS_FILE_PATH
		
		sed --follow-symlinks -i "/\*/b; s/\(\s*'$SETTINGS_SET_DATABASE_NAME_PARAM_NAME'\s*=>\s*\)'.*'/\1'$3'/" $SETTINGS_FILE_PATH

		sed --follow-symlinks -i "/\*/b; s/\(\s*'$SETTINGS_SET_DATABASE_USER_NAME_PARAM_NAME'\s*=>\s*\)'.*'/\1'$4'/" $SETTINGS_FILE_PATH

		sed --follow-symlinks -i "/\*/b; s/\(\s*'$SETTINGS_SET_DATABASE_PASSWORD_PARAM_NAME'\s*=>\s*\)'.*'/\1'$5'/" $SETTINGS_FILE_PATH 

		
		echo "After the change:"

		cat $SETTINGS_FILE_PATH | grep -v "*" | grep -v "#" | grep "'$SETTINGS_SET_DATABASE_SERVER_ADDRESS_PARAM_NAME'"

		cat $SETTINGS_FILE_PATH | grep -v "*" | grep -v "#" | grep "'$SETTINGS_SET_DATABASE_NAME_PARAM_NAME'"

		cat $SETTINGS_FILE_PATH | grep -v "*" | grep -v "#" | grep "'$SETTINGS_SET_DATABASE_USER_NAME_PARAM_NAME'"

		cat $SETTINGS_FILE_PATH | grep -v "*" | grep -v "#" | grep "'$SETTINGS_SET_DATABASE_PASSWORD_PARAM_NAME'"

	fi
fi
